/*
  Cell shader for nuiMesh
  Copyright (C) 2002 Vincent Caron <v.caron@zerodeux.net>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "CellApp.h"
#include "CellWin.h"


/* Create application instance
*/
NGL_APP_CREATE(CellApp);


CellApp::CellApp()
{
	mpWindow = NULL;
}

void CellApp::OnExit (int Code)
{
  if (mpWindow)
    delete mpWindow;
}

void CellApp::OnInit()
{
  uint width = 800, height = 600;
  bool has_size = false;
  bool fullscreen = false;

  // Parse NGL default options
  ParseDefaultArgs();

  int i = 0;
  while (i < GetArgCount())
  {
    nglString arg = GetArg(i);

    if (arg[0] != _T('-'))
      break;

    if ((arg == _T("--size") || arg == _T("-s")) && ((i+1) < GetArgCount()))
    {
      std::vector<nglString> tokens;

      GetArg(i+1).Tokenize(tokens, 'x');
      if (tokens.size() > 0) width  = tokens[0].GetInt();
      if (tokens.size() > 1) height = tokens[1].GetInt();
      has_size = true;
      i++;
    }
    else if (arg == _T("--fullscreen") || arg == _T("-f")) fullscreen = true;
    else if (arg == _T("--help") || arg == _T("-h"))
    {
      NGL_OUT(_T("viewer <filename>\n"));
      Quit();
      return;
    }
    i++;
  }
  
  if (!has_size && fullscreen)
  {
    nglVideoMode current_mode;

    width = current_mode.GetWidth();
    height = current_mode.GetHeight();
  }

  nglPath path = i < GetArgCount() ? nglPath(GetArg(i)) : nglPath(ePathCurrent);

  nglContextInfo Context; // Use default context
  nglWindowInfo Info(width, height, fullscreen);

  mpWindow = new CellWin(Context, Info, path);
  if (mpWindow->GetError())
  {
    NGL_OUT(_T("Error: cannot create window (%s)\n"), mpWindow->GetErrorStr());
    Quit(1);
    return;
  }
}
