/*
  Cell shader for nuiMesh
  Copyright (C) 2002 Vincent Caron <v.caron@zerodeux.net>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

/*!
\file  CellEngine.h
\brief Cell shader renderer for nuiMesh
*/

#ifndef __CellEngine_h__
#define __CellEngine_h__

#include "nuiMeshEngine.h"


#define EDGERAMP_SIZE 256
#define LIGHTRAMP_SIZE 256


class CellEngine : public nuiMeshEngine
{
public:
  GLfloat mEdgeColor[4];
  GLfloat mEdgeThickness;
  GLfloat mEdgeSharpness;
  GLfloat mEdgeFalloff;
  GLfloat mEdgeFalloffOffset;
  GLubyte mEdgeRamp[EDGERAMP_SIZE];

  GLfloat mLightShadeCnt;
  GLfloat mLightFlatness;
  GLfloat mLightGammaX;
  GLfloat mLightGammaY;
  GLfloat mLightAmbient;
  GLubyte mLightRamp[LIGHTRAMP_SIZE];

  CellEngine(nglContext* pContext = NULL);
  virtual ~CellEngine();

  void SetCellLight (uint Index);
  void UpdateLightRamp();
  void UpdateEdgeRamp();

protected:
  virtual void Draw(nuiDrawContext* pContext, const nuiRect& rViewPort);

  void SetupTexture (GLenum Unit, GLenum Target);
  virtual void SetupMaterial(uint Index);

  virtual void OnDraw   (nuiDrawContext* pContext);
  virtual bool OnMesh   (const ngl3DSMesh& rMesh);
  virtual void OnElement(const ngl3DSMesh& rMesh, const ElementType& rElement);

private:
  int     mVertexProgram;
  int     mFragmentProgram;
  GLuint  mLightPosVar;

  uint    mLightIndex;

  void Setup();
  void SetupVertexProgram();
  void SetupFragmentProgram();
};

#endif // __CellEngine_h__
