/*
  Cell shader for nuiMesh
  Copyright (C) 2002 Vincent Caron <v.caron@zerodeux.net>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef __CellMesh_h__
#define __CellMesh_h__

#include "nuiMesh.h"
#include "nuiFileSelector.h"
#include "CellEngine.h"
#include "RampEdit.h"


class CellMesh : public nuiMesh
{
public:
  CellMesh(nuiContainerPtr pParent);
  virtual ~CellMesh();

  // Shader presets
  void Load (const nglPath& rPath);
  void Save (const nglPath& rPath);

protected:
  virtual bool KeyDown (nglKeyCode Key, nglChar Char);

  virtual void StartView (nuiSize X, nuiSize Y);
  virtual bool UpdateView(float DeltaX, float DeltaY);

private:
  nuiFileSelector* mpFileDialog;
  nuiEventSink<CellMesh> mEventSink;

  CellEngine* mpCellEngine;
  uint        mCellLight;

  RampEdit*   mpEdgeEdit;
  RampEdit*   mpLightEdit;

  enum PanMode
  {
    ePanCamera,
    ePanLight
  };
  PanMode                 mPanMode;
  std::vector<nglVectorf> mLightPosRef;

  nglString FormatValue (const nglChar* pName, float Value);
  float     ReadValue   (nuiXMLNode* pNode, const nglChar* pPath);
  bool      OnFileSave  (nuiEvent* pEvent);
  bool      OnFileLoad  (nuiEvent* pEvent);
};


#endif // __CellMesh_h__
