/*
  NUI demonstration sample
  Copyright (C) 2002 Vincent Caron <v.caron@zerodeux.net>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "ViewerWin.h"


ViewerWin::ViewerWin (const nglContextInfo& rContextInfo, const nglWindowInfo& rInfo, const nglPath& rPath) :
  nuiMainWindow(rContextInfo, rInfo, NULL, nglPath(_T("../data/")))
{
  mViewerSink.SetTarget(this);

  mPath = rPath.GetAbsolutePath();
}

void ViewerWin::OnCreation()
{
  bool is_file = mPath.IsLeaf();

  mpSplit = new nuiSplitter(this, nuiHorizontal);

  // Left pane
  mpFileTable = new nuiFileTable(mpSplit, is_file ? mPath.GetParent() : mPath);
  mpFileTable->SetShowType(false);
  mViewerSink.Connect(mpFileTable->Activated, &ViewerWin::OnFileSelected);

  // Right pane
  mpMesh = OnNewMesh(mpSplit);
  mpMesh->Focus();

  if (is_file)
    Load(mPath);

  nglWindow::SetState(eWindowShow);
  
}

void ViewerWin::OnDestruction()
{
  if (mpMesh)
    delete mpMesh;
}

nuiMesh* ViewerWin::OnNewMesh (nuiContainerPtr pParent)
{
  return new nuiMesh(pParent);
}

bool ViewerWin::OnFileSelected(nuiEvent* pEvent)
{
  nuiObjectList selected;

  mpFileTable->GetSelected(selected);
  nglPath path(selected.front()->GetProperty(_T("Path")));
  if (path.IsLeaf() && path.Exists())
    return Load(path.GetPathName());

  return false;
}

bool ViewerWin::Load (const nglPath& rPath)
{
  return mpMesh->Load(rPath);
}
